// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// 3.0?
// TODO: 2.0: File sharing
// TODO: 2.0: Sound recording/playing
// TODO: 2.0: Sending files via e-mail
// TODO: 2.0: Serving selected files via http (cool ;-)
// TODO: 2.0: File dropped on a Desktop shortcut should be imported to the Makagiga tree
// TODO: 2.0: Alarm

// TODO: 2.0: Editor: links to other related files
// TODO: 2.0: function to clear private data (e.g. last open time in meta info)
package org.makagiga;

import static org.makagiga.common.UI._;

import java.io.FileOutputStream;
import java.nio.channels.FileLock;
import javax.swing.SwingUtilities;

import org.makagiga.common.*;
import org.makagiga.console.Console;
import org.makagiga.settings.AdvancedSettings;
import org.makagiga.settings.GeneralSettings;
import org.makagiga.settings.LookAndFeelSettings;

/** The main Makagiga class. */
public final class Main {

	// public

	/**
	 * The main function.
	 * Use @ref org.makagiga.common.Args to access @p args.
	 * @param args A command line arguments
	 * @throws Exception
	 */
	public static final void main(final String[] args) throws Exception {
		// init app info
		AppInfo.copyright.set("(C) 2005-3000 Konrad Twardowski");
		AppInfo.fileInfo.set("Generated by Makagiga, do not modify!");
		AppInfo.fullName.set("Makagiga");
		AppInfo.internalName.set("makagiga");

		// MetaVersion: generated by ant, from build.xml and build.properties
		AppInfo.bugReport.set(MetaVersion.BUG_REPORT);
		AppInfo.buildID.set(MetaVersion.BUILD_ID);
		AppInfo.internalVersion.set(MetaVersion.INTERNAL_VERSION);
		AppInfo.niceVersion.set(MetaVersion.NICE_VERSION);
		AppInfo.www.set(MetaVersion.WWW);

		// init misc
		OS.init();
		initArgs(args);
		// init default config
		Config.setDefaultComment(AppInfo.fileInfo.get());
		new Config().makeGlobal();

		// init system properties
// MUSTANG: new AA API
		System.setProperty("swing.aatext", Boolean.toString(AdvancedSettings.readTextAntialiasing()));
// TODO: 2.0: option: System.setProperty("swing.boldMetal", "false");
// MUSTANG: java.awt.Toolkit.getDefaultToolkit().setDynamicLayout(true);
		// init os
		if (AdvancedSettings.readCustomBrowser())
			OS.customBrowser.set(AdvancedSettings.readBrowserCommand());

		// init ui
		FS.iconSize.set(LookAndFeelSettings.readIconSize());
		UI.customIcons.set(LookAndFeelSettings.readCustomIcons());
		UI.toolTipsDetails.set(GeneralSettings.readToolTipsDetails());
		if (!Args.isSet("safe-mode"))
			LookAndFeelSettings.applyLAF(null, false);

// !!!: file lock sometimes doesn't work [0.9.5]
		// only one instance is allowed ..
		String lockFile = FS.makeConfigPath(AppInfo.internalName + ".lock");
		FileLock lock = new FileOutputStream(lockFile).getChannel().tryLock();
		if (lock == null) {
			if (!MMessage.confirmWithIcon(
				null,
				"makagiga",
				_("It seems that {0} is already running.\n\nPress \"OK\" to run again, or \"Cancel\" to exit."),
				AppInfo.getTitle()
			))
				TK.quit();
		}

		// init console
		Console.IO.redirectOutput();
		MLogger.info(AppInfo.getTitle());

		// init main window
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				MainWindow.getInstance();
			}
		} );
	}

	// private

	private static void initArgs(final String[] args) {
		// init args
		Args.init(args);
		Args.add("no-splash", _("No splash screen"));
		Args.add("safe-mode", _("Safe mode"));
		Args.add("time-demo", _("Used to test the application speed"));
		Args.check();
	}

}
