// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// TODO: 2.0: option to autoopen file at application startup

package org.makagiga;

import static org.makagiga.common.UI._;

import org.makagiga.common.*;

/** A @b Properties dialog. */
public final class PropertiesDialog extends MDialog implements MDialogAction {

	// private

	private MCheckBox locked;
	private MetaInfo metaInfo;
	private MTabbedPane<MPanel> tabs;
	private MTextArea comment;

	// public

	/**
	 * Constructs a @b Properties dialog.
	 * @param parent A parent frame
	 * @param metaInfo A file or folder meta info
	 */
	public PropertiesDialog(final MFrame parent, final MetaInfo metaInfo) {
		super(parent, _("Properties for \"{0}\"", metaInfo), STANDARD_DIALOG);
		this.metaInfo = metaInfo;
		setSize(320, 320);

		tabs = new MTabbedPane<MPanel>();
		tabs.addTab(_("General"), "ui/configure", createGeneralPanel());
		tabs.addTab(_("Comment"), "comment", createCommentPanel());
		addCenter(tabs);

		updateLockedState();
	}

	// MDialogAction

	public void accept() {
		metaInfo.setComment(comment.getText());
		metaInfo.setLocked(locked.isSelected());
	}

	public void reject() { }

	// private

	private MPanel createCommentPanel() {
		MPanel p = MPanel.createBorderPanel();
		comment = new MTextArea(metaInfo.getComment());
		comment.setToolTipText(UI.makeHTML(_("Enter a comment.")));
		p.addCenter(comment);

		return p;
	}

	private MPanel createGeneralPanel() {
		MPanel p = MPanel.createVBoxPanel();
		locked = new MCheckBox() {
			@Override
			public void onToggle(final boolean isSelected) {
				updateLockedState();
			}
		};
		locked.setIcon(FS.getIcon("unlocked"));
		locked.setSelectedIcon(FS.getIcon("locked"));
		locked.setSelected(metaInfo.isLocked());
		locked.setToolTipText(UI.makeHTML(_("Click to lock/unlock the file or folder.<br>Locked file cannot be modified.")));
		p.add(locked);

		return p;
	}

	private void updateLockedState() {
		boolean isLocked = locked.isSelected();
		locked.setText(isLocked ? _("Un&lock") : _("&Lock"));
		comment.setEditable(!isLocked);
	}

}
