// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.util.Iterator;
import java.util.NoSuchElementException;

/** An abstract iterator. */
public abstract class AbstractIterator<I> implements Iterator<I> {

	// private

	private int current;
	private int index;

	// public

	/**
	 * Returns the current index.
	 */
	public int getIndex() { return index; }

	/**
	 * Returns an object at @p index in the collection.
	 */
	public abstract I getObjectAt(final int index);

	/**
	 * Returns the number of objects in the collection.
	 */
	public abstract int getObjectCount();

	/**
	 * Returns @c true if the next object is available.
	 */
	public boolean hasNext() {
		return current < getObjectCount();
	}


	/**
	 * Returns the next object in the collection,
	 * or @c null if exception occured.
	 */
	public I next() throws NoSuchElementException {
		try {
			return getObjectAt(current);
		}
		catch (Exception exception) {
			throw new NoSuchElementException();
		}
		finally {
			index = current;
			current++;
		}
	}

	public int nextIndex() {
		next();

		return index;
	}

	/**
	 * Optional.
	 * Not used in this class.
	 * @throws UnsupportedOperationException
	 */
	public void remove() {
		throw new UnsupportedOperationException();
	}

}
