// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

/** An application Information. */
public final class AppInfo {

	// public

	/**
	 * The build ID number.
	 * (e.g. 666)
	 */
	public static final IntegerProperty buildID = new IntegerProperty();

	/**
	 * The internal version number.
	 * (e.g. @c 0x01090a)
	 * Quick info:
	 * - FORMAT: mmiibb (m - major, i - minor, b - bugfix)
	 * - EXAMPLE: 0x01090a (it's a hex value = "1.9.10")
	 * @b WARNING: This must be a HEX integer!
	 */
	public static final IntegerProperty internalVersion = new IntegerProperty();

	/**
	 * The bug report URL.
	 */
	public static final StringProperty bugReport = new StringProperty();

	/**
	 * The copyright.
	 * (e.g. "(C) 2005 kdt")
	 */
	public static final StringProperty copyright = new StringProperty();

	/**
	 * The file info.
	 * (e.g. "Generated by Makagiga, do not modify!")
	 */
	public static final StringProperty fileInfo = new StringProperty();

	/**
	 * The full name.
	 * (e.g. "Makagiga")
	 */
	public static final StringProperty fullName = new StringProperty();

	/**
	 * The internal name.
	 * (e.g. "makagiga")
	 * Internal name is used as a part of the user configuration directory path.
	 * This name should be file system safe (e.g. no space, local characters or "/").
	 * Internal name should not be changed when application is running.
	 */
	public static final StringProperty internalName = new StringProperty();

	/**
	 * The <b>nice</b> version.
	 * (e.g. "1.9.10 Beta")
	 */
	public static final StringProperty niceVersion = new StringProperty();

	/**
	 * The home page URL without ending <code>/</code>.
	 * (e.g. "http://www.example.com")
	 */
	public static final StringProperty www = new StringProperty();

	// public

	/**
	 * Returns a full name + nice version.
	 * (e.g. "Makagiga 1.9.10 Beta")
	 * @see fullName
	 * @see niceVersion
	 */
	public static String getTitle() { return fullName + " " + niceVersion; }

}
