// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.util.Date;

/** A date property. */
public final class DateProperty extends Property<Date> {

	// public

	/**
	 * Constructs a date property.
	 * It represents the time at which it was allocated.
	 */
	public DateProperty() {
		super(new Date());
	}

	/**
	 * [Based on the java.util.Date API documentation]
	 * Sets this property to represent a point in time that is @p time milliseconds after
	 * January 1, 1970 00:00:00 GMT.
	 * @param value The number of milliseconds
	 */
	public void setTime(final long value) {
		this.value.setTime(value);
	}

}
