// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.util.Locale;
import java.util.ResourceBundle;

/** A text translator. */
public final class Gettext {

	// private

	private static ResourceBundle catalog;

	// static

	/**
	 * Initializes and loads the catalog with translated strings.
	 * Messages for "en" language are not loaded.
	 * The catalog file is stored in "i18n/Messages_LANGCODE.class" file.
	 */
	static {
		String langName = Locale.getDefault().getLanguage();
		if (!langName.equals("en")) {
			String className = "Messages_" + langName;
			try {
				MLogger.info("Loading messages: " + className);
				Class c = Gettext.class.getClassLoader().loadClass(className);
				catalog = (ResourceBundle)c.newInstance();
			}
			catch (Exception exception) {
// !!!: try to load messages from the user home directory
				MLogger.warning("%s: Could not load language. Missing CLASSPATH? (%s)", exception, className);
			}
		}
	}

	// public

	/**
	 * Translates the specified text.
	 * Do not call this function directly. Use "_" instead.
	 * @param id A text to translate
	 * @return A translated string
	 */
	public static String translate(final String id) {
		if (catalog == null)
			return id;

		try {
			return catalog.getString(id);
		}
		catch (Exception exception) {
			return id;
		}
	}

}
