// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import static javax.swing.SwingConstants.*;

import static org.makagiga.common.UI._;

/**
 * An @b About dialog.
 * Displays information about the application (name, version, copyright, etc).
 */
public final class MAbout extends MDialog {

	// public

	/**
	 * Constructs an @b About dialog.
	 * @param parent A parent frame
	 */
	public MAbout(final MFrame parent) {
		super(parent, _("About"), MODAL | OK_BUTTON | OPTIONS_BUTTON);
		getOptionsButton().setText(_("Report Bug..."));

		// logo
		MLabel l = new MLabel(FS.getDefaultIcon("makagiga"));
		l.setVerticalAlignment(TOP);
		addWest(l);

		MPanel p = MPanel.createVBoxPanel();
		p.setMargin(0, 5, 0, 0);
		// full name
		l = new MLabel(AppInfo.fullName.get());
		l.setFont(l.getFont().deriveFont(24f));
		p.add(l);
		// -
		p.addGap();
		// version and build
		p.add(new MLabel(AppInfo.niceVersion + " [Build " + AppInfo.buildID + "]"));
		// -
		p.addGap();
		// copyright
		p.add(new MLabel(AppInfo.copyright.get()));
		// -
		p.addGap();
		// links
		p.add(new MURLButton(_("Home Page"), AppInfo.www.get()));
		p.add(new MURLButton(_("License"), "http://www.apache.org/licenses/LICENSE-2.0"));
		p.add(new MURLButton(_("Download Java{0}", UI.TM), "http://java.com/en/download/index.jsp"));
		addCenter(p);

		pack();
		setResizable(false);
		getOKButton().requestFocusInWindow();
	}

	@Override
	public void onOptions() {
		OS.launchBrowser(AppInfo.bugReport.get());
	}

}
