// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.Icon;
import javax.swing.JButton;

/** A button. */
public class MButton extends JButton implements ActionListener {

	// public

	/**
	 * Constructs a new button with no text.
	 */
	public MButton() {
		this(null, null);
	}

	/**
	 * Constructs a button.
	 * @param icon An icon
	 */
	public MButton(final Icon icon) {
		this(null, icon);
	}

	/**
	 * Constructs a new button.
	 * @param text A text (& - mnemonic)
	 */
	public MButton(final String text) {
		this(text, null);
	}

	/**
	 * Constructs a new button.
	 * @param text A text (& - mnemonic)
	 * @param icon An icon
	 */
	public MButton(final String text, final Icon icon) {
		super(text, icon);
		addActionListener(this);
	}

	/**
	 * Overriden to call @ref onClick.
	 * @param e An action event
	 */
	public final void actionPerformed(final ActionEvent e) {
		onClick();
	}

	/**
	 * Overriden to handle mnemonics.
	 * @param text A new text (& - mnemonic)
	 */
	@Override
	public void setText(final String text) {
		super.setText(UI.setTextWithMnemonic(this, text));
	}

	// protected

	/**
	 * Invoked when an action occurs.
	 */
	protected void onClick() { }

}
