// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import javax.swing.JMenuItem;

/** A menu item. */
public class MMenuItem extends JMenuItem {

	// public

	/**
	 * Constructs a new menu item.
	 * @param action An action
	 */
	public MMenuItem(final AppAction action) {
		super(action);
		if (UI.toolTipsDetails.get())
			setToolTipText(action.getHTMLHelp());
		char mnemonic = action.getMnemonic();
		if (mnemonic != 0)
			setMnemonic(mnemonic);
	}

	/**
	 * Constructs a new menu item.
	 * @param text A text
	 */
	public MMenuItem(final String text) {
		super(text);
	}

	/**
	 * Returns the action associated with this menu item.
	 */
	public AppAction getAction() {
		return (AppAction)super.getAction();
	}

	// protected

	/**
	 * Converts menu item to "check box" menu item.
	 */
	protected void setCheckBox() {
		AppAction action = getAction();

		if (!(action instanceof AppToggleAction))
			return;

		AppToggleAction toggleAction = (AppToggleAction)action;

		toggleAction.setButton(this);
		setIcon(FS.getIcon(toggleAction.isSelected() ? "ui/checked" : "ui/unchecked", FS.DEFAULT_ICON_SIZE));
		setSelected(toggleAction.isSelected());
	}

}
