// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.Rectangle;
import java.awt.event.MouseEvent;
import java.awt.event.MouseWheelEvent;
import javax.swing.JComponent;
import javax.swing.JScrollPane;

/** A scroll pane (pane with scroll bars). */
public class MScrollPane extends JScrollPane {

	// public

	/**
	 * Constructs a new scroll pane.
	 * @param component A component to add to the scroll pane
	 */
	public MScrollPane(final JComponent component) {
		super(component);
	}

	public static void autoScroll(final JComponent component, final int x, final int y) {
		component.scrollRectToVisible(new Rectangle(x, y, 1, 1));
	}

	/**
	 * Scrolls a component.
	 * Quick info:
	 * - Alt - scroll horizontally
	 * - Ctrl - double scroll speed
	 * @param component A component to scroll
	 * @param e A mouse wheel event
	 */
	public static void mouseWheelScroll(final JComponent component, final MouseWheelEvent e) {
		if (component == null)
			return;

		if (e == null)
			return;

		Rectangle r = component.getVisibleRect();

		if (r == null)
			return;

		int speed = e.getWheelRotation() * 30;

		// ctrl - double speed
		if (e.isControlDown())
			speed *= 2;

		// alt - scroll horizontally
		if (e.isAltDown())
			r.translate(speed, 0);
		else
			r.translate(0, speed);

		component.scrollRectToVisible(r);
	}

}
