// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.Dimension;
import java.awt.event.MouseWheelEvent;
import java.awt.event.MouseWheelListener;
import javax.swing.JComponent;
import javax.swing.JSpinner;
import javax.swing.JTextField;

/** An abstract spinner. */
public abstract class MSpinner extends JSpinner implements MouseWheelListener {

	// public

	/**
	 * Constructs a new spinner.
	 */
	public MSpinner() {
		addMouseWheelListener(this);
	}

	@Override
	public Dimension getMaximumSize() {
		// do not stretch vertically
		return new Dimension(super.getMaximumSize().width, getPreferredSize().height + (MText.MARGIN * 2));
	}

	/**
	 * Mouse wheel event handler.
	 * Increments/decrements spinner value.
	 * @param e A mouse wheel event
	 */
	public void mouseWheelMoved(final MouseWheelEvent e) {
		UI.fire(
			(e.getWheelRotation() < 0)
				? "increment"
				: "decrement",
			this
		);
	}

	// protected

	/**
	 * Installs @ref MText on this text field editor.
	 */
	protected void setupEditor() {
		JComponent editor = getEditor();
		if (editor instanceof DefaultEditor) {
			JTextField textField = DefaultEditor.class.cast(editor).getTextField();
			textField.setDragEnabled(true);
			// no setMargin
			MText.install(textField);
		}
	}

}
