// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import static java.awt.event.KeyEvent.*;

import java.awt.Dimension;
import java.awt.event.FocusListener;
import javax.swing.Action;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;

/** A text field. */
public class MTextField extends JTextField {

	// public

	/**
	 * Constructs a new text field.
	 */
	public MTextField() {
		this(null);
	}

	/**
	 * Constructs a new text field.
	 * @param text An initial text
	 */
	public MTextField(final String text) {
		super(text);
		setMaximumSize(
			new Dimension(
				Integer.MAX_VALUE,
				getPreferredSize().height + (MText.MARGIN * 2)
			)
		);
		MText.commonSetup(this);
		getDocument().addDocumentListener(new DocumentListener() {
			public void changedUpdate(final DocumentEvent e) {
				onChange(e);
			}
			public void insertUpdate(final DocumentEvent e) {
				onChange(e);
			}
			public void removeUpdate(final DocumentEvent e) {
				onChange(e);
			}
		} );
	}

	/**
	 * Sets text to @c null.
	 */
	public void clear() {
		setText(null);
	}
	
	public boolean isEmpty() {
		return TK.isEmpty(getText());
	}

	@Override
	public void selectAll() {
		requestFocusInWindow();
		super.selectAll();
	}

	public void setDefault() {
		selectAll();
	}

	/**
	 * Connects @p action with the @c VK_ENTER key.
	 * The action is executed only if the text field has focus.
	 */
	public void setEnterPressAction(final Action action) {
		action.putValue(Action.NAME, "MTextField.setEnterPressAction");
		UI.connect(this, UI.WHEN_FOCUSED, VK_ENTER, action);
	}

	// protected

	protected void onChange(final DocumentEvent e) { }

}
