// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.Dimension;
import java.awt.event.MouseEvent;
import javax.swing.Action;
import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JToolBar;

/** A tool bar. */
public class MToolBar extends JToolBar {

	// public

	public static final int SHOW_TEXT = 1 << 0; /**< Show button text. */

	// public

	/**
	 * Constructs a new tool bar.
	 * Defaults:
	 * - Not floatable
	 * - Rollovers are enabled
	 * - Border is not painted
	 */
	public MToolBar() {
// TODO: 2.0: floatable and configurable
		setBorderPainted(false);
		setFloatable(false);
		setRollover(true);
	}

	/**
	 * Adds a new action.
	 * @param action An action
	 * @return An action button
	 */
	@Override
	public JButton add(final Action action) {
		return add(action, 0);
	}

	/**
	 * Adds a new action.
	 * @param action An action
	 * @param flags Flags (e.g. @ref SHOW_TEXT)
	 * @return An action button
	 */
	public JButton add(final Action action, final int flags) {
		final JButton b = super.add(action);
		if (UI.isMetal()) {
			b.addMouseListener(new MMouseAdapter() {
				@Override
				public void mouseEntered(final MouseEvent e) {
					if (b.isEnabled()) {
						b.setBorderPainted(true);
						b.setContentAreaFilled(true);
					}
				}
				@Override
				public void mouseExited(final MouseEvent e) {
					b.setBorderPainted(false);
					b.setContentAreaFilled(false);
				}
			} );
			b.setBorderPainted(false);
			b.setContentAreaFilled(false);
		}
		String text = (String)action.getValue(Action.NAME);
		if ((flags & SHOW_TEXT) != 0) {
			// text alongside icon
			b.setHorizontalTextPosition(RIGHT);
			b.setVerticalTextPosition(CENTER);
			b.setText(text);
		}
		else {
			b.setToolTipText(UI.makeHTML(text));
		}

		return b;
	}

	public void addGap() {
		if (getOrientation() == VERTICAL)
			add(Box.createRigidArea(new Dimension(0, 5)));
		else
			add(Box.createRigidArea(new Dimension(5, 0)));
	}

	/**
	 * Adds a horizontal stretch.
	 */
	public void addStretch() {
		if (getOrientation() == VERTICAL)
			add(Box.createVerticalGlue());
		else
			add(Box.createHorizontalGlue());
	}

}
