// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.TreePath;

/**
 * A tree item.
 * The tree item is used in @ref MTree.
 */
public class MTreeItem<V extends Object> extends DefaultMutableTreeNode {

	// public

	/**
	 * Returns an object associated with this item.
	 */
	@SuppressWarnings("unchecked")
	public V getData() { return (V)userObject; }

	/**
	 * Associates @p value with this item.
	 */
	public void setData(final V value) { userObject = value; }

	/**
	 * Returns the parent item, root item, or @c null if @b root item.
	 */
	public MTreeItem getParentItem() {
		return (MTreeItem)getParent();
	}

	/**
	 * Returns tree path.
	 */
	public TreePath getTreePath() {
		return new TreePath(getPath());
	}

	/**
	 * Returns @c true if item has subitems.
	 */
	public boolean hasItems() {
		return getChildCount() > 0;
	}

}
