// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import static java.awt.Color.*;

import static org.makagiga.common.UI._;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

/**
 * An URL button.
 *
 * EXAMPLE:
 * @code
 * ...
 * MURLButton button = new MURLButton(
 *   "Example Link", // a link name
 *   "http://www.example.com/" // an url to open
 * );
 * add(button);
 * ...
 * @endcode
 */
public class MURLButton extends MButton {

	// private

	private String url;

	// public

	public MURLButton(final String text) {
		this(text, null);
	}

	/**
	 * Constructs a new URL button.
	 * @param text A link name
	 * @param url An URL to open
	 * @see FS.getIcon
	 */
	public MURLButton(final String text, final String url) {
		this.url = url;
		setBorderPainted(false);
		setContentAreaFilled(false);
		setForeground(BLUE);
		setHorizontalAlignment(LEFT);
		setURL(text, url);
		UI.setHandCursor(this, true);
		addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(final MouseEvent e) {
				setForeground(RED);
			}
			@Override
			public void mouseExited(final MouseEvent e) {
				setForeground(BLUE);
			}
		} );
	}

	/**
	 * Sets the text and URL of this button.
	 * @param text A link name
	 * @param url An URL to open
	 */
	public void setURL(final String text, final String url) {
		setText((text == null) ? url : text);
		if (TK.isEmpty(url))
			setToolTipText(null);
		else
			setToolTipText(UI.makeHTML(_("Open {0}", HTMLBuilder.createLink(url))));
	}

	// protected

	/**
	 * Override to handle action or mouse click event.
	 * By default this function opens the current URL
	 * in the current web browser.
	 */
	@Override
	protected void onClick() {
		OS.launchBrowser(url);
	}

}
