// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.common;

import java.awt.Component;
import javax.swing.DefaultListCellRenderer;
import javax.swing.JList;

/**
 * A simple list cell renderer.
 * The @ref onRender function is called after @ref getListCellRendererComponent.
 *
 * EXAMPLE:
 * @code
 * ...
 * MComboBox<Integer> comboBox = new MComboBox<Integer>();
 * comboBox.setRenderer(new SimpleListCellRenderer<Integer>() {
 *   public void onRender(final Integer value) {
 *     setText(value + " %");
 *   }
 * } );
 * ...
 * @endcode
 */
public abstract class SimpleListCellRenderer<V> extends DefaultListCellRenderer {

	// protected

	protected boolean hasFocus;

	/**
	 * @c true if currently rendered cell is selected.
	 */
	protected boolean selected;

	// public

	/**
	 * Overriden to call @ref onRender.
	 * @param list A list
	 * @param value A value
	 * @param index An item index
	 * @param selected @c true if cell is selected
	 * @param hasFocus @c true if cell has focus
	 */
	@Override
	@SuppressWarnings("unchecked")
	public Component getListCellRendererComponent(
		final JList list,
		final Object value,
		final int index,
		final boolean selected,
		final boolean hasFocus
	) {
		super.getListCellRendererComponent(
			list,
			value,
			index,
			selected,
			hasFocus
		);
		this.hasFocus = hasFocus;
		this.selected = selected;
		onRender((V)value);

		return this;
	}

	/**
	 * Called from @ref getListCellRendererComponent.
	 * @param value A value
	 */
	public abstract void onRender(final V value);

}
