// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors;

import org.makagiga.common.*;

/**
 * An editor configuration load/save interface.
 *
 * EXAMPLE:
 * @code
 * ...
 * public void loadConfig(final Config global, final Config local) {
 *   myValue = local.readInt(getConfigEntry("myValue"), 0);
 * }
 *
 * public void saveConfig(final Config global, final Config local) {
 *   local.write(getConfigEntry("myValue"), myValue);
 * }
 * ...
 * @endcode
 * @see org.makagiga.common.Config
 * @see Editor.getConfigEntry
 */
public interface EditorConfig {

	// public

	/**
	 * Implement to load editor configuration.
	 * This function is called @b after @ref org.makagiga.editors.Editor.loadFromFile.
	 * @param global A global configuration
	 * @param local A local configuration
	 */
	public void loadConfig(final Config global, final Config local);

	/**
	 * Implement to save editor configuration.
	 * This function is called @b before @ref org.makagiga.editors.Editor.saveToFile.
	 * @param global A global configuration
	 * @param local A local configuration
	 * @see Editor.syncConfig
	 */
	public void saveConfig(final Config global, final Config local);

}
