// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors;

import java.awt.print.PrinterException;

// MUSTANG: text component print (http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=4791649)
// TODO: 2.0: all editors
/** The "Print" interface for editors. */
public interface EditorPrint {

	// public

	/**
	 * Invoked when the "Print" action occurs.
	 * Do not display any error messages. @b Makagiga will do it for you.
	 * Just return @c false or throw @c PrinterException.
	 *
	 * EXAMPLE:
	 * @code
	 * ...
	 * public boolean printDocument() throws PrinterException {
	 *   // print table
	 *   return table.print();
	 * }
	 * ...
	 * @endcode
	 * @return @c true if print was succesfull; otherwise @c false
	 * @throws PrinterException A printer exception
	 */
	public boolean printDocument() throws PrinterException;

}
