// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import static org.makagiga.common.UI._;

/** A "todo" editor column. */
public enum Column {

	// public

	/**
	 * The "Done" column.
	 */
	DONE(_("Done"), 10),

	/**
	 * The "Summary" column.
	 */
	SUMMARY(_("Summary"), 350),

	/**
	 * The "Priority" column.
	 */
	PRIORITY(_("Priority"), 40),

	/**
	 * The "Complete" column.
	 */
	COMPLETE(_("Complete"), 20),

	/**
	 * The "Date/Time" column.
	 */
	DATE_TIME(_("Date/Time"), 50);

	public static final Column LAST = DATE_TIME; /**< The last column. */

	// private

	private int preferredWidth;
	private String name;

	// public

	/**
	 * Returns the preferred column width.
	 */
	public int getPreferredWidth() { return preferredWidth; }

	/**
	 * Returns the column name. (e.g. "Priority")
	 */
	@Override
	public String toString() { return name; }

	// private

	private Column(final String name, final int preferredWidth) {
		this.preferredWidth = preferredWidth;
		this.name = name;
	}

}
