// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import static java.awt.Color.*;

import java.awt.Component;
import java.text.ParseException;
import java.util.Date;
import java.util.EventObject;
import javax.swing.AbstractCellEditor;
import javax.swing.BorderFactory;
import javax.swing.JTable;
import javax.swing.table.TableCellEditor;

import org.makagiga.common.*;

/** A "Date/Time" column editor. */
public final class DateTimeEditor extends AbstractCellEditor implements TableCellEditor {

	// private

	private MDateSpinner spinner;

	// public

	/**
	 * Constructs a new date/time editor.
	 */
	public DateTimeEditor() {
		spinner = new MDateSpinner();
	}

	/**
	 * Returns the active editor value.
	 */
	public Object getCellEditorValue() {
		return spinner.getValue();
	}

	/**
	 * Returns the cell editor component.
	 * @param table A "todo" table
	 * @param value A date/time value
	 * @param isSelected @c true if cell is selected
	 * @param row A row
	 * @param column A column
	 */
	public Component getTableCellEditorComponent(
		JTable table,
		Object value,
		boolean isSelected,
		int row,
		int column
	) {
		spinner.setBorder(BorderFactory.createLineBorder(BLACK, 2));
		Date date = (Date)value;
		spinner.setValue((date.getTime() == 0) ? DT.now() : date);

		return spinner;
	}

	/**
	 * Returns @c true if editing can be started.
	 */
	@Override
	public boolean isCellEditable(final EventObject e) {
		return true; // single click
	}

	/**
	 * Commits edited data and stops edition.
	 */
	@Override
	public boolean stopCellEditing() {
		try {
			spinner.commitEdit();

			return super.stopCellEditing();
		}
		catch (ParseException exception) {
			MLogger.exception(exception);

			return false;
		}
	}

}
