// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import java.awt.Component;
import java.awt.Rectangle;
import javax.swing.JTable;
import javax.swing.table.TableCellRenderer;

import org.makagiga.common.*;

/** The @b Done column editor. */
public final class DoneComponent extends MCheckBox implements TableCellRenderer {

	// public

	/**
	 * Constructs a @b Done column editor.
	 */
	public DoneComponent() {
		setBorderPainted(true);
		setHorizontalAlignment(CENTER);
		setOpaque(true);
	}

	/**
	 * Returns the table cell renderer component.
	 * @param table A table
	 * @param value A value - @c true if task is completed
	 * @param isSelected @c true if cell is selected
	 * @param hasFocus @c true if cell has focus
	 * @param row A table row
	 * @param column A table column
	 */
	public Component getTableCellRendererComponent(
		JTable table,
		Object value,
		boolean isSelected,
		boolean hasFocus,
		int row,
		int column
	) {
		if (isSelected) {
			setBackground(table.getSelectionBackground());
			setForeground(table.getSelectionForeground());
		}
		else {
			SimpleTableCellRenderer.setColors(table, this, row);
		}
		setSelected((value != null) && (Boolean)value);
		MTable.setupCellBorder(this, hasFocus);

		return this;
	}

	// overriden for performance reasons.

	/**
	 * Overriden for performance reasons.
	 */
	@Override
	public void invalidate() { }

	/**
	 * Overriden for performance reasons.
	 */
	@Override
	public void repaint() { }

	/**
	 * Overriden for performance reasons.
	 * @param r Not used
	 */
	@Override
	public void repaint(final Rectangle r) { }

	/**
	 * Overriden for performance reasons.
	 * @param tm Not used
	 * @param x Not used
	 * @param y Not used
	 * @param width Not used
	 * @param height Not used
	 */
	@Override
	public void repaint(final long tm, final int x, final int y, final int width, final int height) { }

	/**
	 * Overriden for performance reasons.
	 */
	@Override
	public void revalidate() { }

	/**
	 * Overriden for performance reasons.
	 */
	@Override
	public void validate() { }

}
