// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import static java.awt.Color.*;

import static org.makagiga.common.UI._;

import java.awt.Color;

/**
 * A priority.
 * Used in @b Priority column.
 */
public enum Priority {

	// public

	/**
	 * Very low priority (@b 0).
	 */
	VERY_LOW(_("Very Low"), new Color(0xc0ffc0)),

	/**
	 * Low priority (@b 1).
	 */
	LOW(_("Low"), new Color(0x00c000)),

	/**
	 * Normal priority (@b 2).
	 */
	NORMAL(_("Normal"), null),

	/**
	 * High priority (@b 3).
	 */
	HIGH(_("High"), YELLOW),

	/**
	 * Very high priority (@b 4).
	 */
	VERY_HIGH(_("Very High"), RED);

	public static final Priority DEFAULT = NORMAL; /**< The default priority. */

	// private

	private Color color;
	private String name;

	// public

	/**
	 * Converts an @c int @p value to @c Priority value.
	 */
	public static Priority fromInt(final int value) {
		for (Priority i : values()) {
			if (value == i.ordinal())
				return i;
		}

		return DEFAULT;
	}

	/**
	 * Converts a @c String @p value to @c Priority value.
	 */
	public static Priority fromString(final String value) {
		try {
			return fromInt(Integer.parseInt(value));
		}
		catch (NumberFormatException exception) {
			return Priority.DEFAULT;
		}
	}

	/**
	 * Returns @c this priority color.
	 */
	public Color getColor() { return color; }

	/**
	 * Returns @c this priority name. (e.g. "Very Low" for @ref VERY_LOW)
	 */
	@Override
	public String toString() { return name; }

	// private

	private Priority(final String name, final Color color) {
		this.color = color;
		this.name = name;
	}

}
