// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.editors.todo;

import static java.awt.Color.*;

import java.awt.Color;
import javax.swing.JLabel;

import org.makagiga.common.*;

/** The @b Priority column renderer. */
public final class PriorityRenderer extends SimpleTableCellRenderer<Priority> {

	// public

	/**
	 * Constructs a @b Priority renderer.
	 */
	public PriorityRenderer() {
		setHorizontalAlignment(CENTER);
	}

	/**
	 * Setups the renderer.
	 * @param value An item priority
	 * @see setupRenderer
	 */
	public void onRender(final Priority value) {
		setupRenderer(this, value, false);
	}

	/**
	 * Setups the renderer.
	 * This shared function is also used in the @ref PriorityEditor.
	 * @param renderer A renderer to setup
	 * @param priority An item priority
	 * @param selected @c true if row is selected
	 */
	public static void setupRenderer(final JLabel renderer, final Priority priority, final boolean selected) {
		Color c = priority.getColor();
		if (c != null) {
			renderer.setBackground(c);
			renderer.setForeground(BLACK);
		}
		renderer.setText(priority.toString());//!!!!
	}

}
