// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.plugins;

import org.makagiga.common.*;

/**
 * The menu interface for plugins.
 *
 * EXAMPLE:
 * @code
 * ...
 * public void updateMenu(final String type, final MMenu menu) {
 *   if (type.equals(EDIT_MENU)) {
 *     menu.add(cutAction);
 *     menu.add(copyAction);
 *     menu.add(pasteAction);
 *   }
 * }
 *
 * public void updateToolBar(final String type, final MToolBar toolBar) {
 *   if (type.equals(EDITOR_TOOL_BAR)) {
 *     toolBar.add(cutAction);
 *     toolBar.add(copyAction);
 *     toolBar.add(pasteAction);
 *   }
 * }
 * ...
 * @endcode
 */
public interface PluginMenu {

	// public

	// menus
	public static final String EDIT_MENU = "EDIT_MENU"; /**< "Edit" menu. */
	public static final String VIEW_MENU = "VIEW_MENU"; /**< "View" menu. */

	// tool bars
	public static final String EDITOR_TOOL_BAR = "EDITOR_TOOL_BAR"; /**< Editor tool bar. */

	/**
	 * Invoked when plugin (e.g. editor) should add items to the menu.
	 * This function may be called many times.
	 * @param type A menu type
	 * @param menu A menu component
	 */
	public void updateMenu(final String type, final MMenu menu);

	/**
	 * Invoked when plugin (e.g. editor) should add items to the tool bar.
	 * This function may be called many times.
	 * @param type A tool bar type
	 * @param toolBar A tool bar component
	 */
	public void updateToolBar(final String type, final MToolBar toolBar);

}
