// Copyright 2005 Konrad Twardowski
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.makagiga.settings;

import static org.makagiga.common.UI._;

import javax.swing.ButtonGroup;

import org.makagiga.common.*;

/** The @b Advanced settings page. */
public final class AdvancedSettings extends SettingsPage implements SettingsAction {

	// private

	private boolean textAntialiasingOriginal;
	private MCheckBox textAntialiasing;
	private MComboBox<String> browserCommand;
	private MRadioButton customBrowser;
	private MRadioButton defaultBrowser;

	// public

	/**
	 * Constructs the @b Advanced settings page.
	 */
	public AdvancedSettings() {
		super(_("Advanced"));

// !!!: "Test" button
		// browser
		MPanel browserPanel = MPanel.createTitledPanel(_("Internet Browser"));
		defaultBrowser = new MRadioButton(_("&Use Default Browser")) {
			@Override
			public void onToggle(final boolean isSelected) {
				browserCommand.setEnabled(!isSelected);
			}
		};
		browserPanel.addNorth(defaultBrowser);
		customBrowser = new MRadioButton(_("Use Custom &Browser:")) {
			@Override
			public void onToggle(final boolean isSelected) {
				browserCommand.setEnabled(isSelected);
			}
		};
		browserPanel.addWest(customBrowser);
		browserCommand = new MComboBox<String>();
		browserCommand.setEditable(true);
		browserCommand.setToolTipText(UI.makeHTML(_("Enter a command.")));
		// sync. with OS.launchBrowser
		browserCommand.addItem("firefox");
		browserCommand.addItem("konqueror");
		browserCommand.addItem("mozilla");
		browserCommand.addItem("netscape");
		browserCommand.addItem("opera");
// TODO: 2.0: test safari command
		if (OS.isMac())
			browserCommand.addItem("safari");
		browserPanel.addCenter(browserCommand);
		ButtonGroup browserButtonGroup = new ButtonGroup();
		browserButtonGroup.add(defaultBrowser);
		browserButtonGroup.add(customBrowser);
		addNorth(browserPanel);

		// gui
		MPanel guiPanel = MPanel.createTitledPanel(_("GUI"));
		textAntialiasing = new MCheckBox(_("&Text Antialiasing"));
		guiPanel.addCenter(textAntialiasing);
		addSouth(guiPanel);
	}

	/**
	 * Returns the custom browser command or @c null.
	 */
	public static String readBrowserCommand() {
		return Config.getGlobal().read("OS.browserCommand");
	}

	/**
	 * Returns @c true if custom browser is enabled.
	 */
	public static boolean readCustomBrowser() {
		return Config.getGlobal().read("OS.customBrowser", false);
	}

	/**
	 * Returns @c true if text antialiasing is enabled.
	 */
	public static boolean readTextAntialiasing() {
		return Config.getGlobal().read("GUI.textAntialiasing", false);
	}

	// SettingsAction

	public void onInit() {
		// browser
		customBrowser.setSelected(readCustomBrowser());
		defaultBrowser.setSelected(!customBrowser.isSelected());
		browserCommand.setText(readBrowserCommand());
		browserCommand.setEnabled(customBrowser.isSelected());
		// gui
		textAntialiasing.setSelected(readTextAntialiasing());
		textAntialiasingOriginal = textAntialiasing.isSelected();
	}

	public void onOK() {
		Config config = Config.getGlobal();
		// browser
		config.write("OS.customBrowser", customBrowser.isSelected());
		config.write("OS.browserCommand", browserCommand.getText());
		OS.customBrowser.set(customBrowser.isSelected() ? browserCommand.getText() : null);
		// gui
		config.write("GUI.textAntialiasing", textAntialiasing.isSelected());

// !!!: MCheckBox.isChange
		needRestart.set(textAntialiasing.isSelected() != textAntialiasingOriginal);
	}

}
