#!/bin/sh

INSTALL_PREFIX=/usr/local
OUT_FILE=

if [ -n "${1}" ]; then
	INSTALL_PREFIX="${1}"
fi

UNINSTALLER="${INSTALL_PREFIX}/share/makagiga/uninstall.sh"

function mg_install
{
	OUT_FILE="${INSTALL_PREFIX}/${2}/${1}"
	echo "Installing '${OUT_FILE}'..."
	echo "rmdir \"${INSTALL_PREFIX}/${2}\"" >> "${UNINSTALLER}.tmp"
	echo "rm -f \"${OUT_FILE}\"" >> "${UNINSTALLER}.tmp"
	mkdir -p "${INSTALL_PREFIX}/${2}"
	cp "${1}" "${INSTALL_PREFIX}/${2}"
}

function mg_install_dir
{
	OUT_FILE="${INSTALL_PREFIX}/${1}"
	echo "Installing '${OUT_FILE}'..."
	echo "rmdir \"${INSTALL_PREFIX}/${1}\"" >> "${UNINSTALLER}.tmp"
	mkdir -p "${INSTALL_PREFIX}/${1}"
}

mkdir -p "${INSTALL_PREFIX}/share/makagiga"
if [ ! -w "${INSTALL_PREFIX}" ]; then
	echo
	echo "ERROR: No permissions to write to '${INSTALL_PREFIX}'!"
	echo "       Possible solutions:"
	echo "       - Run the installer as the 'root' user (e.g. su -c \"./install.sh\")."
	echo "       - Change the installation directory (prefix) (e.g. ./install.sh ~/myapps)."
	exit 1
fi

echo > "${UNINSTALLER}.tmp"

# launchers
mg_install "makagiga" "bin"
mg_install "makagiga.desktop" "share/applications"

# icon
mg_install "makagiga.png" "share/icons/hicolor/32x32/apps"

# core
mg_install "LICENSE.txt" "share/makagiga"
mg_install "README.html" "share/makagiga"
mg_install "i18n.jar" "share/makagiga"
mg_install "images.jar" "share/makagiga"
mg_install "makagiga.jar" "share/makagiga"
mg_install_dir "share/makagiga/i18n"
mg_install_dir "share/makagiga/plugins"

# setup makagiga launcher
sed "s?\@@INSTALL_PREFIX@@?${INSTALL_PREFIX}?g" "${INSTALL_PREFIX}/bin/makagiga" > "${INSTALL_PREFIX}/bin/makagiga.tmp"
mv "${INSTALL_PREFIX}/bin/makagiga.tmp" "${INSTALL_PREFIX}/bin/makagiga"
chmod +x "${INSTALL_PREFIX}/bin/makagiga"

# setup makagiga.desktop launcher
sed "s?\@@INSTALL_PREFIX@@?${INSTALL_PREFIX}?g" "${INSTALL_PREFIX}/share/applications/makagiga.desktop" > "${INSTALL_PREFIX}/share/applications/makagiga.desktop.tmp"
mv "${INSTALL_PREFIX}/share/applications/makagiga.desktop.tmp" "${INSTALL_PREFIX}/share/applications/makagiga.desktop"

# setup installer
echo "#!/bin/sh" > "${UNINSTALLER}"
echo "rm -f \"${UNINSTALLER}\"" >> "${UNINSTALLER}"
# first remove files, then dirs
cat "${UNINSTALLER}.tmp" | sort -r >> "${UNINSTALLER}"
rm "${UNINSTALLER}.tmp"
chmod +x "${INSTALL_PREFIX}/share/makagiga/uninstall.sh"

echo
echo "Thank you for using Makagiga!"
echo
MAKAGIGA_LAUNCHER=`which makagiga 2>/dev/null`
if [ -z "${MAKAGIGA_LAUNCHER}" ]; then
	echo "- Type '${INSTALL_PREFIX}/bin/makagiga' to run Makagiga."
else
	echo "- Type 'makagiga' to run Makagiga."
fi
echo "- Run '${UNINSTALLER}' to uninstall Makagiga."
echo "- Make sure you have installed Java 5.0."
echo "  You can download Java from 'http://java.com/en/download/index.jsp'."
echo
